@@ -1,12 +1,14 @@
+/*
+ * Copyright (c) 2021 The Software Heritage developers
+ * See the AUTHORS file at the top-level directory of this distribution
+ * License: GNU General Public License version 3, or any later version
+ * See top-level LICENSE file for more information
+ */
+
 package org.softwareheritage.graph.utils;
 
 import it.unimi.dsi.big.webgraph.LazyLongIterator;
-import it.unimi.dsi.fastutil.BigArrays;
-import it.unimi.dsi.fastutil.io.BinIO;
-import org.softwareheritage.graph.AllowedEdges;
-import org.softwareheritage.graph.Graph;
-import org.softwareheritage.graph.Node;
-import org.softwareheritage.graph.SWHID;
+import org.softwareheritage.graph.*;
 
 import java.io.IOException;
 import java.time.Duration;
@@ -36,13 +38,13 @@ public class FindEarliestRevision {
 
         System.err.println("loading transposed graph...");
         ts = System.nanoTime();
-        Graph graph = Graph.loadMapped(graphPath).transpose();
+        SwhBidirectionalGraph graph = SwhBidirectionalGraph.loadMapped(graphPath).transpose();
         elapsed = Duration.ofNanos(System.nanoTime() - ts);
         System.err.println(String.format("transposed graph loaded (duration: %s).", elapsed));
 
         System.err.println("loading revision timestamps...");
         ts = System.nanoTime();
-        long[][] committerTimestamps = BinIO.loadLongsBig(graphPath + "-rev_committer_timestamps.bin");
+        graph.loadCommitterTimestamps();
         elapsed = Duration.ofNanos(System.nanoTime() - ts);
         System.err.println(String.format("revision timestamps loaded (duration: %s).", elapsed));
 
@@ -81,16 +83,19 @@ public class FindEarliestRevision {
             long minTimestamp = Long.MAX_VALUE;
             while (!stack.isEmpty()) {
                 long currentNodeId = stack.pop();
-                if (graph.getNodeType(currentNodeId) == Node.Type.REV) {
-                    long committerTs = BigArrays.get(committerTimestamps, currentNodeId);
+                if (graph.getNodeType(currentNodeId) == SwhType.REV) {
+                    long committerTs = graph.getCommitterTimestamp(currentNodeId);
                     if (committerTs < minTimestamp) {
                         minRevId = currentNodeId;
                         minTimestamp = committerTs;
                     }
                 }
 
-                LazyLongIterator it = graph.successors(currentNodeId, edges);
+                LazyLongIterator it = graph.successors(currentNodeId);
                 for (long neighborNodeId; (neighborNodeId = it.nextLong()) != -1;) {
+                    if (!edges.isAllowed(graph.getNodeType(currentNodeId), graph.getNodeType(neighborNodeId))) {
+                        continue;
+                    }
                     if (!visited.contains(neighborNodeId)) {
                         stack.push(neighborNodeId);
                         visited.add(neighborNodeId);
@@ -106,11 +111,10 @@ public class FindEarliestRevision {
             if (timing) {
                 elapsedNanos = System.nanoTime() - ts; // processing time for current SWHID
                 elapsed = elapsed.plus(Duration.ofNanos(elapsedNanos)); // cumulative processing time for all SWHIDs
-                System.err.println(String.format("visit time (s):\t%.6f", (double) elapsedNanos / 1_000_000_000));
+                System.err.printf("visit time (s):\t%.6f\n", (double) elapsedNanos / 1_000_000_000);
             }
         }
         if (timing)
-            System.err.println(String.format("processed %d SWHIDs in %s (%s avg)", lineCount, elapsed,
-                    elapsed.dividedBy(lineCount)));
+            System.err.printf("processed %d SWHIDs in %s (%s avg)\n", lineCount, elapsed, elapsed.dividedBy(lineCount));
     }
 }
